const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const path = require('path');

const ROOT_PATH = path.resolve(__dirname);
const SRC_PATH = path.resolve(ROOT_PATH, 'src');
const DIST_PATH = path.resolve(ROOT_PATH, 'dist');
const SVG_PATH = path.resolve(SRC_PATH, 'svg');
const INDEX_FILE = path.resolve(SRC_PATH, 'index.js');

module.exports = {
  entry: [
    INDEX_FILE,
  ],
  output: {
    filename: 'dcoos-api-editor.js',
    library: 'DcoosApiEditor',
    libraryTarget: 'umd',
  },
  module: {
    rules: [
      {
        test: /(\.jsx|\.js)$/,
        use: ['babel-loader'],
        include: SRC_PATH,
        exclude: path.resolve(ROOT_PATH, 'node_modules'),
      },
      {
        test: /(\.txt|\.yaml)$/,
        use: ['raw-loader'],
      },
      {
        test: /\.worker\.js$/,
        use: [
          {
            loader: 'worker-loader',
            options: {
              name: '[name].js',
              inline: true,
            }
          },
          {
            loader: 'babel-loader',
          },
        ],
      },
      {
        test: /\.svg$/,
        include: SVG_PATH,
        use: ['svg-sprite-loader'],
      },
      {
        test: /\.css$/,
        include: SRC_PATH,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader', 'postcss-loader'],
        }),
      },
      {
        test: /\.scss$/,
        include: SRC_PATH,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader', 'postcss-loader', 'sass-loader'],
        }),
      },
      {
        test: /\.less$/,
        include: SRC_PATH,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader', 'postcss-loader', 'less-loader'],
        }),
      },
      {
        test: /\.(png|svg|jpe?g|gif)$/i,
        include: SRC_PATH,
        exclude: SVG_PATH,
        use: [
          {
            loader: 'url-loader',
            options: {
              limit: 8192,
              name: 'images/[hash:8].[name].[ext]',
            },
          },
        ],
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf)$/,
        include: SRC_PATH,
        use: ['file-loader'],
      },
    ],
  },
  plugins: [
    new ExtractTextPlugin('dcoos-api-editor.css'),
  ],
  resolve: {
    extensions: ['.js', '.jsx', '.less', '.scss', '.css'],
    alias: {
      '@': SRC_PATH,
    },
  },
};